@@ -3,16 +3,18 @@ import torch
 import torch.nn as nn
 from ray.rllib.utils import override
 
-from raylab.losses import ClippedDoubleQLearning
-from raylab.policy import TargetNetworksMixin
 from raylab.policy import TorchPolicy
+from raylab.policy.action_dist import WrapDeterministicPolicy
+from raylab.policy.losses import ClippedDoubleQLearning
+from raylab.pytorch.nn.utils import update_polyak
 from raylab.pytorch.optim import build_optimizer
 
 
-class NAFTorchPolicy(TargetNetworksMixin, TorchPolicy):
+class NAFTorchPolicy(TorchPolicy):
     """Normalized Advantage Function policy in Pytorch to use with RLlib."""
 
     # pylint: disable=abstract-method
+    dist_class = WrapDeterministicPolicy
 
     def __init__(self, *args, **kwargs):
         super().__init__(*args, **kwargs)
@@ -26,15 +28,15 @@ class NAFTorchPolicy(TargetNetworksMixin, TorchPolicy):
     @override(TorchPolicy)
     def get_default_config():
         """Return the default config for NAF."""
-        # pylint: disable=cyclic-import
-        from raylab.agents.naf import DEFAULT_CONFIG
+        # pylint: disable=cyclic-import,protected-access
+        from raylab.agents.naf import NAFTrainer
 
-        return DEFAULT_CONFIG
+        return NAFTrainer._default_config
 
     @override(TorchPolicy)
     def make_module(self, obs_space, action_space, config):
         module_config = config["module"]
-        module_config["type"] = "NAFModule"
+        module_config["type"] = "NAFModule-v0"
         module_config["double_q"] = config["clipped_double_q"]
         module_config["perturbed_policy"] = (
             config["exploration_config"]["type"]
@@ -57,7 +59,9 @@ class NAFTorchPolicy(TargetNetworksMixin, TorchPolicy):
             loss.backward()
 
         info.update(self.extra_grad_info())
-        self.update_targets("vcritics", "target_vcritics")
+        update_polyak(
+            self.module.vcritics, self.module.target_vcritics, self.config["polyak"]
+        )
         return info
 
     @torch.no_grad()
